DynamoTableMethods

Trait DynamoTableMethods 

pub trait DynamoTableMethods: DynamoTable
where Self::PK: Display + Clone + Send + Sync + Debug + PartialEq, Self::SK: Display + Clone + Send + Sync + Debug + PartialEq,
{ // Provided methods fn left_diff( left: Vec<Self>, right: Vec<CompositeKey<Self::PK, Self::SK>>, ) -> Vec<Self> { ... } fn right_diff( left: Vec<Self>, right: Vec<CompositeKey<Self::PK, Self::SK>>, ) -> Vec<CompositeKey<Self::PK, Self::SK>> { ... } }
Convenience methods over DynamoTable using associated key types

Provided Methods

fn left_diff( left: Vec<Self>, right: Vec<CompositeKey<Self::PK, Self::SK>>, ) -> Vec<Self>

Visits the values representing the difference, i.e., the values that are in self but not in other.

fn right_diff( left: Vec<Self>, right: Vec<CompositeKey<Self::PK, Self::SK>>, ) -> Vec<CompositeKey<Self::PK, Self::SK>>

Visits the values representing the difference, i.e., the values that are in other but not in self.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors