pub trait DynamoTableMethods: DynamoTablewhere
Self::PK: Display + Clone + Send + Sync + Debug + PartialEq,
Self::SK: Display + Clone + Send + Sync + Debug + PartialEq,{
// Provided methods
fn left_diff(
left: Vec<Self>,
right: Vec<CompositeKey<Self::PK, Self::SK>>,
) -> Vec<Self> { ... }
fn right_diff(
left: Vec<Self>,
right: Vec<CompositeKey<Self::PK, Self::SK>>,
) -> Vec<CompositeKey<Self::PK, Self::SK>> ⓘ { ... }
}Expand description
Convenience methods over DynamoTable using associated key types
Provided Methods
Sourcefn left_diff(
left: Vec<Self>,
right: Vec<CompositeKey<Self::PK, Self::SK>>,
) -> Vec<Self>
fn left_diff( left: Vec<Self>, right: Vec<CompositeKey<Self::PK, Self::SK>>, ) -> Vec<Self>
Visits the values representing the difference, i.e., the values that are in self but not in other.
Sourcefn right_diff(
left: Vec<Self>,
right: Vec<CompositeKey<Self::PK, Self::SK>>,
) -> Vec<CompositeKey<Self::PK, Self::SK>> ⓘ
fn right_diff( left: Vec<Self>, right: Vec<CompositeKey<Self::PK, Self::SK>>, ) -> Vec<CompositeKey<Self::PK, Self::SK>> ⓘ
Visits the values representing the difference, i.e., the values that are in other but not in self.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.